;----------------------------------------------------------------------------------
;	FILE:			TwoChannel-ISR.ASM
;
;	Description:	2 Output DC/DC closed loop control system, with ADC
;					s/w drivers, and a 2-pole/2-zero compensation/control law.
;
;	Version: 		1.0
;
;   Target:  		TMS320F280x
;
;	Type: 			Device dependent
;
;----------------------------------------------------------------------------------
;  Copyright Texas Instruments  2004-2007
;----------------------------------------------------------------------------------
;  Revision History:
;----------------------------------------------------------------------------------
;  Date	     | Description
;----------------------------------------------------------------------------------
; 30 Aug-07  | Release 1.0  		2 Channel Internal release (DAF)
;----------------------------------------------------------------------------------

;----------------------------------------------------------------------------------
	.include "PeripheralAddress_ASM.h"

	; MACRO includes
	.include "ADC_NchDrv.asm"
	.include "ControlLaw2P2Z.asm"
	.include "DataLogTST.asm"
	.include "BuckSingle_PwmDrv.asm"
	.include "BuckSingleHR_PwmDrv.asm"

;===============================================================
; Incremental Build options for System check-out
; Note: Select only one build option
;---------------------------------------------------------------
IB1			.set	1	; Open Loop - Channels 1,2
IB2			.set	0	; Closed loop - Ch1 only using separate lib blocks

;**********************************************************************************
; Declare Public functions for External Reference
;**********************************************************************************
				.def 	_ISR_Init
				.def 	_ISR_Run

;**********************************************************************************
; Variable declaration
;**********************************************************************************	
; All Terminal modules initially point to the ZeroNet to ensure a known
; start state. Pad extra locations to accomodate unwanted ADC results.
ZeroNet			.usect "Net_terminals",8,1,1
DummyNet	 	.usect "Net_terminals",7,1,1
IsrClkCtr		.usect "Net_terminals",1

_DLogBuffer1	.usect "GraphData",300,1,1

				; Used by C environment
				;----------------------
				.def 	_DLogBuffer1

				.text
;---------------------------------------------------------
; ISR Initialisation
;---------------------------------------------------------
_ISR_Init:

; Clear the ZeroNet
	MOVL 	XAR2,#ZeroNet
	RPT		#7 ; 8 times
	||MOV	*XAR2++, #0

	;---------------------------------------------------------
	.if(IB1)
		BuckSingle_DRV_INIT	1	; EPWM1A
		BuckSingle_DRV_INIT	2	; EPWM2A
	.endif
	;---------------------------------------------------------
	.if(IB2)
		ADC_NchDRV_INIT	1		; 1 Channel, N=1
		ControlLaw_2P2Z_INIT 1
		BuckSingleHR_DRV_INIT 1	; EPWM1A
		DataLogTST_INIT	1		; 1 Channel Data logger
	.endif
	;---------------------------------------------------------

	LRETR

			.sect "ramfuncs"

;---------------------------------------------------------
; ISR Run
;---------------------------------------------------------
_ISR_Run:	;(13 cycles to get to here from ISR trigger)
	;CONTEXT_SAVE
	PUSH AR1H:AR0H ; 32-bit
	PUSH XAR2 ; 32-bit
	PUSH XAR3 ; 32-bit
	PUSH XAR4 ; 32-bit
;-- Comment these to save cycles --------
	PUSH XAR5 ; 32-bit
	PUSH XAR6 ; 32-bit
	PUSH XAR7 ; 32-bit
;----------------------------------------
	PUSH XT	  ; 32-bit
	NOP		

	;---------------------------------------------------------
	.if(IB1)
		BuckSingle_DRV	1			; EPWM1A
		BuckSingle_DRV	2			; EPWM2A
	.endif
	;---------------------------------------------------------
	.if(IB2)
		ADC_NchDRV	1				; 1 Channel, N=1
		ControlLaw_2P2Z 1
		BuckSingleHR_DRV 1			; EPWM1A
		DataLogTST	1				; 1 Channel Data logger
ADC_Reset:
		MOVW 	DP,#ADCTRL2>>6		; Reset ADC SEQ
		MOV 	@ADCTRL2,#0x4101	; RST_SEQ1=1, SOCA-SEQ1=1, SOCB-SEQ2=1
	.endif
	;---------------------------------------------------------

;===================================
EXIT_ISR
;===================================
; Interrupt management before exit
	MOVW 	DP,#ETCLR1>>6
	MOV 	@ETCLR1,#0x01			; Clear EPWM1 Int flag
	MOVW 	DP,#PIEACK>>6			; Acknowledge PIE interrupt Group 3
	MOV 	@PIEACK,#PIEACK_GROUP3

; Restore context & return
	POP XT
;-- Comment these to save cycles ---
	POP XAR7
	POP XAR6
	POP XAR5
;-----------------------------------
	POP XAR4
	POP XAR3
	POP XAR2
	POP AR1H:AR0H

	IRET						

